@@ -8,6 +8,7 @@ use Module::Load;
 use App::Tel::HostRange qw (check_hostrange);
 use App::Tel::Passwd;
 use App::Tel::Color;
+use App::Tel::Macro;
 use Time::HiRes qw ( sleep );
 use v5.10;
 
@@ -18,11 +19,11 @@ App::Tel - A script for logging into devices
 
 =head1 VERSION
 
-0.201507
+0.201508
 
 =cut
 
-our $VERSION = '0.201507';
+our $VERSION = '0.201508';
 
 
 =head1 SYNOPSIS
@@ -88,6 +89,7 @@ sub new {
         'enabled'       => 0,
         'title_stack'   => 0,
         'log_stdout'    => 1,
+        'profile'       => {},
     };
 
     bless($self, 'App::Tel');
@@ -1011,9 +1013,11 @@ sub control_loop {
     @args = split(/;/, $opts->{c}) if ($opts->{c});
 
     if ($opts->{x}) {
-        open(my $X, '<', $opts->{x}) || die "Can't open file $opts->{x}\n";
-        @args = <$X>;
-        close $X;
+        for (@{$opts->{x}}) {
+            open(my $X, '<', $_) || die "Can't open file $_\n";
+            push(@args,<$X>);
+            close $X;
+        }
     }
 
     if (@args) {
@@ -1042,26 +1046,4 @@ sub control_loop {
     }
 }
 
-=head2 handle_backspace
-
-Handle backspace for routers that use ^H
-
-=cut
-
-sub handle_backspace {
-    ${$_[0]}->send("\b");
-    return 1;
-}
-
-=head2 handle_ctrl_z
-
-Handle ctrl_z for non-cisco boxes
-
-=cut
-
-sub handle_ctrl_z {
-    ${$_[0]}->send("exit\r");
-    return 1;
-}
-
 1;
